
![Logo](docs/logo.png)


`picaso` enables the: 1) computation of exoplanet and brown dwarf spectroscopy in transmission, emission or reflected light, 2) 1D climate modeling of brown dwarfs and exoplanets, 3) fitting spectroscopic data to models with grids and retrievals.

- Website: https://natashabatalha.github.io/picaso/index.html 
- Installation: https://natashabatalha.github.io/picaso/installation.html
- Tutorials: https://natashabatalha.github.io/picaso/tutorials.html
- Workshops: https://natashabatalha.github.io/picaso/workshops.html
- Source code: https://github.com/natashabatalha/picaso
- Contributing: https://natashabatalha.github.io/picaso/contribution.html
- Bug reports: https://github.com/natashabatalha/picaso/issues
- Physics help: https://natashabatalha.github.io/picaso_dev 
- What to cite: https://natashabatalha.github.io/picaso/credit.html 

## Major Features

- [Reflected Light Spectroscopy of planets](https://natashabatalha.github.io/picaso/notebooks/1_GetStarted.html)
- [Thermal Emission Spectroscopy of planets and brown dwarfs](https://natashabatalha.github.io/picaso/tutorials.html#basics-of-thermal-emission)
- [Transit Spectroscopy of planets](https://natashabatalha.github.io/picaso/notebooks/5_AddingTransitSpectrum.html)
- [Phase Curves of planets](https://natashabatalha.github.io/picaso/notebooks/9e_PhaseCurves.html)
- [1D Climate modeling of planets and brown dwarfs](https://natashabatalha.github.io/picaso/notebooks/climate/12a_BrownDwarf.html)
- [Fitting models to data](https://natashabatalha.github.io/picaso/notebooks/fitdata/GridSearch.html)

## Contributing

Contributions are always welcome no matter the code level you are at. We value anything from small typos in our documentations page to larger feature changes. We follow the [all-contributors](https://github.com/all-contributors/all-contributors) specification. This means that contributions of any kind welcome! If you are a new to GitHub and conda environments you can read our instructions here: https://natashabatalha.github.io/picaso/contribution.html

Additionally all contributors agree to adhere to this project's [`code of conduct`](https://github.com/natashabatalha/picaso/blob/master/code_of_conduct.md)

Anyone is free to use the [contributor bot to add their contribution](https://allcontributors.org/docs/en/bot/usage). Simply comment on an issue or pull request with: 

```
@all-contributors please add @<username> for <contributions>
```

## Contributors

<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-14-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END -->

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):
<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="http://natashabatalha.github.io"><img src="https://avatars.githubusercontent.com/u/6554465?v=4?s=100" width="100px;" alt="Natasha Batalha"/><br /><sub><b>Natasha Batalha</b></sub></a><br /><a href="https://github.com/natashabatalha/picaso/commits?author=natashabatalha" title="Code">💻</a> <a href="#mentoring-natashabatalha" title="Mentoring">🧑‍🏫</a> <a href="#maintenance-natashabatalha" title="Maintenance">🚧</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/Rangertreaty33"><img src="https://avatars.githubusercontent.com/u/106419391?v=4?s=100" width="100px;" alt="Roman St. Gerard"/><br /><sub><b>Roman St. Gerard</b></sub></a><br /><a href="https://github.com/natashabatalha/picaso/commits?author=Rangertreaty33" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://www.thinkkappi.com"><img src="https://avatars.githubusercontent.com/u/4071244?v=4?s=100" width="100px;" alt="Kappibw"/><br /><sub><b>Kappibw</b></sub></a><br /><a href="https://github.com/natashabatalha/picaso/issues?q=author%3AKappibw" title="Bug reports">🐛</a> <a href="https://github.com/natashabatalha/picaso/commits?author=Kappibw" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/lcmayor"><img src="https://avatars.githubusercontent.com/u/13788703?v=4?s=100" width="100px;" alt="Laura C. Mayorga"/><br /><sub><b>Laura C. Mayorga</b></sub></a><br /><a href="https://github.com/natashabatalha/picaso/issues?q=author%3Alcmayor" title="Bug reports">🐛</a> <a href="https://github.com/natashabatalha/picaso/commits?author=lcmayor" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://www.linkedin.com/in/ehsan-gharib-nezhad/"><img src="https://avatars.githubusercontent.com/u/22139918?v=4?s=100" width="100px;" alt="Ehsan Gharib-Nezhad"/><br /><sub><b>Ehsan Gharib-Nezhad</b></sub></a><br /><a href="#data-EhsanGharibNezhad" title="Data">🔣</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/caoimherooney11"><img src="https://avatars.githubusercontent.com/u/24413015?v=4?s=100" width="100px;" alt="Caoimhe Rooney"/><br /><sub><b>Caoimhe Rooney</b></sub></a><br /><a href="#research-caoimherooney11" title="Research">🔬</a> <a href="https://github.com/natashabatalha/picaso/commits?author=caoimherooney11" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/sagnickm"><img src="https://avatars.githubusercontent.com/u/55552916?v=4?s=100" width="100px;" alt="Sagnick Mukherjee"/><br /><sub><b>Sagnick Mukherjee</b></sub></a><br /><a href="#research-sagnickm" title="Research">🔬</a> <a href="https://github.com/natashabatalha/picaso/commits?author=sagnickm" title="Code">💻</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/ninarobbins"><img src="https://avatars.githubusercontent.com/u/43654406?v=4?s=100" width="100px;" alt="Nina Robbins Blanch"/><br /><sub><b>Nina Robbins Blanch</b></sub></a><br /><a href="https://github.com/natashabatalha/picaso/commits?author=ninarobbins" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/MartianColonist"><img src="https://avatars.githubusercontent.com/u/22718554?v=4?s=100" width="100px;" alt="Ryan MacDonald"/><br /><sub><b>Ryan MacDonald</b></sub></a><br /><a href="https://github.com/natashabatalha/picaso/issues?q=author%3AMartianColonist" title="Bug reports">🐛</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://epl.carnegiescience.edu/people/peter-gao"><img src="https://avatars.githubusercontent.com/u/20616506?v=4?s=100" width="100px;" alt="Peter Gao"/><br /><sub><b>Peter Gao</b></sub></a><br /><a href="https://github.com/natashabatalha/picaso/issues?q=author%3Asirpetergao" title="Bug reports">🐛</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/nklewis"><img src="https://avatars.githubusercontent.com/u/16822846?v=4?s=100" width="100px;" alt="Nikole Lewis"/><br /><sub><b>Nikole Lewis</b></sub></a><br /><a href="https://github.com/natashabatalha/picaso/issues?q=author%3Anklewis" title="Bug reports">🐛</a> <a href="#mentoring-nklewis" title="Mentoring">🧑‍🏫</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/exoBD"><img src="https://avatars.githubusercontent.com/u/38989139?v=4?s=100" width="100px;" alt="Mark Marley"/><br /><sub><b>Mark Marley</b></sub></a><br /><a href="#mentoring-exobd" title="Mentoring">🧑‍🏫</a> <a href="#ideas-exobd" title="Ideas, Planning, & Feedback">🤔</a> <a href="#research-exobd" title="Research">🔬</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/drtkat"><img src="https://avatars.githubusercontent.com/u/10516244?v=4?s=100" width="100px;" alt="Tiffany Kataria"/><br /><sub><b>Tiffany Kataria</b></sub></a><br /><a href="https://github.com/natashabatalha/picaso/issues?q=author%3Adrtkat" title="Bug reports">🐛</a> <a href="#mentoring-drtkat" title="Mentoring">🧑‍🏫</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/jjfplanet"><img src="https://avatars.githubusercontent.com/u/42284609?v=4?s=100" width="100px;" alt="jjfplanet"/><br /><sub><b>jjfplanet</b></sub></a><br /><a href="#ideas-jjfplanet" title="Ideas, Planning, & Feedback">🤔</a> <a href="#mentoring-jjfplanet" title="Mentoring">🧑‍🏫</a> <a href="#fundingFinding-jjfplanet" title="Funding Finding">🔍</a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->



[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](code_of_conduct.md)

